Remove references to assignee in ts code.
Assignee is no longer supported in Web UI code. Remove remaining
references to it.
Google-Bug-Id: b/267456422
Release-Notes: skip
Change-Id: Ifba52ecf25a1d8c3705d60655d9bcb45fa2669bd
diff --git a/polygerrit-ui/app/elements/change-list/gr-change-list/gr-change-list_test.ts b/polygerrit-ui/app/elements/change-list/gr-change-list/gr-change-list_test.ts
index 312f384..bef3166 100644
--- a/polygerrit-ui/app/elements/change-list/gr-change-list/gr-change-list_test.ts
+++ b/polygerrit-ui/app/elements/change-list/gr-change-list/gr-change-list_test.ts
@@ -513,7 +513,6 @@
test('obsolete column in preferences not visible', () => {
assert.isTrue(element.isColumnEnabled('Subject'));
- assert.isFalse(element.isColumnEnabled('Assignee'));
});
test('showStar and showNumber', async () => {
diff --git a/polygerrit-ui/app/elements/change/gr-reply-dialog/gr-reply-dialog.ts b/polygerrit-ui/app/elements/change/gr-reply-dialog/gr-reply-dialog.ts
index 218594b..f3c23aa 100644
--- a/polygerrit-ui/app/elements/change/gr-reply-dialog/gr-reply-dialog.ts
+++ b/polygerrit-ui/app/elements/change/gr-reply-dialog/gr-reply-dialog.ts
@@ -588,7 +588,7 @@
border: 1px solid var(--border-color);
border-radius: var(--border-radius);
margin-top: var(--spacing-m);
- background-color: var(--assignee-highlight-color);
+ background-color: var(--line-item-highlight-color);
}
.attentionTip div gr-icon {
margin-right: var(--spacing-s);
diff --git a/polygerrit-ui/app/styles/gr-change-list-styles.ts b/polygerrit-ui/app/styles/gr-change-list-styles.ts
index 3763213..34cf872 100644
--- a/polygerrit-ui/app/styles/gr-change-list-styles.ts
+++ b/polygerrit-ui/app/styles/gr-change-list-styles.ts
@@ -14,11 +14,11 @@
background-color: var(--selection-background-color);
}
gr-change-list-item[highlight] {
- background-color: var(--assignee-highlight-color);
+ background-color: var(--line-item-highlight-color);
}
gr-change-list-item[highlight][selected],
gr-change-list-item[highlight]:focus {
- background-color: var(--assignee-highlight-selection-color);
+ background-color: var(--line-item-highlight-selection-color);
}
.groupTitle td,
.cell {
diff --git a/polygerrit-ui/app/styles/themes/dark-theme.ts b/polygerrit-ui/app/styles/themes/dark-theme.ts
index c6884a6..198a906 100644
--- a/polygerrit-ui/app/styles/themes/dark-theme.ts
+++ b/polygerrit-ui/app/styles/themes/dark-theme.ts
@@ -123,8 +123,8 @@
/* directly derived from primary background colors */
/* empty, because inheriting from app-theme is just fine
/* unique background colors */
- --assignee-highlight-color: #3a361c;
- --assignee-highlight-selection-color: #423e24;
+ --line-item-highlight-color: #3a361c;
+ --line-item-highlight-selection-color: #423e24;
--chip-selected-background-color: #3c4455;
--edit-mode-background-color: #5c0a36;
--emphasis-color: #383f4a;
diff --git a/polygerrit-ui/app/styles/themes/app-theme.ts b/polygerrit-ui/app/styles/themes/app-theme.ts
index 6dbda3e..e6dc7ac 100644
--- a/polygerrit-ui/app/styles/themes/app-theme.ts
+++ b/polygerrit-ui/app/styles/themes/app-theme.ts
@@ -248,10 +248,13 @@
--table-subheader-background-color: var(--background-color-tertiary);
--view-background-color: var(--background-color-primary);
/* unique background colors */
+ /* TODO: Remove assignee colors once references are migrated */
--assignee-highlight-color: #fcfad6;
- /* TODO: Find a nicer way to combine the --assignee-highlight-color and the
- --selection-background-color than to just invent another unique color. */
--assignee-highlight-selection-color: #f6f4d0;
+ --line-item-highlight-color: #fcfad6;
+ /* TODO: Find a nicer way to combine the --line-item-highlight-color and the
+ --selection-background-color than to just invent another unique color. */
+ --line-item-highlight-selection-color: #f6f4d0;
--chip-selected-background-color: var(--blue-50);
--edit-mode-background-color: #ebf5fb;
--emphasis-color: #fff9c4;